#!/bin/bash

set -e

if [ -v PASSWORD_FILE ]; then
    PASSWORD="$(< $PASSWORD_FILE)"
fi

# Utiliser les valeurs des variables d'environnement ou les valeurs par défaut
: ${HOST:=${DB_HOST:='db'}}       # Mettre à jour ici le nom du conteneur PostgreSQL
: ${PORT:=${DB_PORT:=5432}}
: ${USER:=${DB_USER:='postgresadmin'}}  # Utilisez l'utilisateur défini dans votre config
: ${PASSWORD:=${DB_PASS:='admin123'}}  # Utilisez le mot de passe défini dans votre config

DB_ARGS=()
function check_config() {
    param="$1"
    value="$2"
    if grep -q -E "^\s*\b${param}\b\s*=" "$ODOO_RC" ; then       
        value=$(grep -E "^\s*\b${param}\b\s*=" "$ODOO_RC" |cut -d " " -f3|sed 's/["\n\r]//g')
    fi;
    DB_ARGS+=("--${param}")
    DB_ARGS+=("${value}")
}

check_config "db_host" "$HOST"
check_config "db_port" "$PORT"
check_config "db_user" "$USER"
check_config "db_password" "$PASSWORD"

case "$1" in
    -- | odoo)
        shift
        if [[ "$1" == "scaffold" ]] ; then
            exec odoo "$@"
        else
            wait-for-psql.py ${DB_ARGS[@]} --timeout=30
            exec odoo "$@" "${DB_ARGS[@]}" 
        fi
        ;;
    -*)
        wait-for-psql.py ${DB_ARGS[@]} --timeout=30
        exec odoo "$@" "${DB_ARGS[@]}" 
        ;;
    *)
        exec "$@"
esac

exit 1

